@@ -9,11 +9,10 @@ from fastapi import Request
 from fastapi.responses import Response
 from fastapi.templating import Jinja2Templates
 
-from . import globals
+from . import background_tasks, globals
 from .dependencies import generate_js_imports, generate_vue_content
 from .element import Element
 from .favicon import get_favicon_url
-from .task_logger import create_task
 
 if TYPE_CHECKING:
     from .page import page
@@ -30,7 +29,8 @@ class Client:
 
         self.elements: Dict[int, Element] = {}
         self.next_element_id: int = 0
-        self.is_waiting_for_handshake: bool = False
+        self.is_waiting_for_connection: bool = False
+        self.is_waiting_for_disconnect: bool = False
         self.environ: Optional[Dict[str, Any]] = None
         self.shared = shared
 
@@ -80,26 +80,40 @@ class Client:
             'favicon_url': get_favicon_url(self.page, prefix),
             'dark': str(self.page.resolve_dark()),
             'prefix': prefix,
+            'tailwind': globals.tailwind,
             'socket_io_js_extra_headers': globals.socket_io_js_extra_headers,
         }, status_code, {'Cache-Control': 'no-store', 'X-NiceGUI-Content': 'page'})
 
-    async def handshake(self, timeout: float = 3.0, check_interval: float = 0.1) -> None:
-        self.is_waiting_for_handshake = True
+    async def connected(self, timeout: float = 3.0, check_interval: float = 0.1) -> None:
+        '''Blocks execution until the client is connected.'''
+        self.is_waiting_for_connection = True
         deadline = time.time() + timeout
         while not self.environ:
             if time.time() > deadline:
-                raise TimeoutError(f'No handshake after {timeout} seconds')
+                raise TimeoutError(f'No connection after {timeout} seconds')
             await asyncio.sleep(check_interval)
-        self.is_waiting_for_handshake = False
+        self.is_waiting_for_connection = False
+
+    async def disconnected(self, check_interval: float = 0.1) -> None:
+        '''Blocks execution until the client disconnects.'''
+        self.is_waiting_for_disconnect = True
+        while self.id in globals.clients:
+            await asyncio.sleep(check_interval)
+        self.is_waiting_for_disconnect = False
 
     async def run_javascript(self, code: str, *,
                              respond: bool = True, timeout: float = 1.0, check_interval: float = 0.01) -> Optional[str]:
+        '''Allows execution of javascript on the client.
+
+        The client connection must be established before this method is called.
+        You can do this by `await client.connected()` or register a callback with `client.on_connected(...)`.
+        If respond is True, the javascript code must return a string.'''
         request_id = str(uuid.uuid4())
         command = {
             'code': code,
             'request_id': request_id if respond else None,
         }
-        create_task(globals.sio.emit('run_javascript', command, room=self.id))
+        background_tasks.create(globals.sio.emit('run_javascript', command, room=self.id))
         if not respond:
             return None
         deadline = time.time() + timeout
@@ -111,4 +125,10 @@ class Client:
 
     def open(self, target: Union[Callable, str]) -> None:
         path = target if isinstance(target, str) else globals.page_routes[target]
-        create_task(globals.sio.emit('open', path, room=self.id))
+        background_tasks.create(globals.sio.emit('open', path, room=self.id))
+
+    def on_connect(self, handler: Union[Callable, Awaitable]) -> None:
+        self.connect_handlers.append(handler)
+
+    def on_disconnect(self, handler: Union[Callable, Awaitable]) -> None:
+        self.disconnect_handlers.append(handler)
