@@ -1,12 +1,14 @@
+from typing import Optional
+
+from ..dependencies import register_component
 from ..element import Element
-from ..vue import register_component
 
 register_component('log', __file__, 'log.js')
 
 
 class Log(Element):
 
-    def __init__(self, max_lines: int = None) -> None:
+    def __init__(self, max_lines: Optional[int] = None) -> None:
         """Log view
 
         Create a log view that allows to add new lines without re-transmitting the whole history to the client.
