@@ -1,14 +1,12 @@
 import traceback
 from dataclasses import dataclass
 from inspect import signature
-from typing import TYPE_CHECKING, Any, Callable, List, Optional
+from typing import TYPE_CHECKING, Any, BinaryIO, Callable, List, Optional
 
-from . import globals
+from . import background_tasks, globals
 from .async_updater import AsyncUpdater
 from .client import Client
-from .functions.lifecycle import on_startup
 from .helpers import is_coroutine
-from .task_logger import create_task
 
 if TYPE_CHECKING:
     from .element import Element
@@ -64,18 +62,11 @@ class JoystickEventArguments(EventArguments):
     y: Optional[float] = None
 
 
-@dataclass
-class UploadFile:
-    content: bytes
-    name: str
-    lastModified: float
-    size: int
-    type: str
-
-
 @dataclass
 class UploadEventArguments(EventArguments):
-    files: List[UploadFile]
+    content: BinaryIO
+    name: str
+    type: str
 
 
 @dataclass
@@ -281,8 +272,8 @@ def handle_event(handler: Optional[Callable], arguments: EventArguments) -> None
                 with arguments.sender.parent_slot:
                     await AsyncUpdater(result)
             if globals.loop and globals.loop.is_running():
-                create_task(wait_for_result(), name=str(handler))
+                background_tasks.create(wait_for_result(), name=str(handler))
             else:
-                on_startup(wait_for_result())
+                globals.app.on_startup(wait_for_result())
     except Exception:
         traceback.print_exc()
