@@ -1,11 +1,11 @@
 import asyncio
 import functools
+import inspect
 from contextlib import nullcontext
 from typing import Any, Awaitable, Callable, Optional, Union
 
-from . import globals
+from . import background_tasks, globals
 from .client import Client
-from .task_logger import create_task
 
 
 def is_coroutine(object: Any) -> bool:
@@ -20,14 +20,14 @@ def safe_invoke(func: Union[Callable, Awaitable], client: Optional[Client] = Non
             async def func_with_client():
                 with client or nullcontext():
                     await func
-            create_task(func_with_client())
+            background_tasks.create(func_with_client())
         else:
             with client or nullcontext():
-                result = func()
+                result = func(client) if len(inspect.signature(func).parameters) == 1 and client is not None else func()
             if isinstance(result, Awaitable):
                 async def result_with_client():
                     with client or nullcontext():
                         await result
-                create_task(result_with_client())
+                background_tasks.create(result_with_client())
     except:
         globals.log.exception(f'could not invoke {func}')
