@@ -4,22 +4,22 @@ import urllib.parse
 from pathlib import Path
 from typing import Dict, Optional
 
-from fastapi import FastAPI, HTTPException, Request
+from fastapi import HTTPException, Request
 from fastapi.middleware.gzip import GZipMiddleware
 from fastapi.responses import FileResponse, Response
 from fastapi.staticfiles import StaticFiles
 from fastapi_socketio import SocketManager
 
-from . import binding, globals
+from . import background_tasks, binding, globals
+from .app import App
 from .client import Client
 from .dependencies import js_components, js_dependencies
 from .element import Element
 from .error import error_content
 from .helpers import safe_invoke
 from .page import page
-from .task_logger import create_task
 
-globals.app = app = FastAPI()
+globals.app = app = App()
 globals.sio = sio = SocketManager(app=app)._sio
 
 app.add_middleware(GZipMiddleware)
@@ -51,9 +51,9 @@ def handle_startup(with_welcome_message: bool = True) -> None:
     globals.loop = asyncio.get_running_loop()
     for t in globals.startup_handlers:
         safe_invoke(t)
-    create_task(binding.loop())
-    create_task(prune_clients())
-    create_task(prune_slot_stacks())
+    background_tasks.create(binding.loop())
+    background_tasks.create(prune_clients())
+    background_tasks.create(prune_slot_stacks())
     globals.state = globals.State.STARTED
     if with_welcome_message:
         print(f'NiceGUI ready to go on http://{globals.host}:{globals.port}')
@@ -64,8 +64,6 @@ def handle_shutdown() -> None:
     globals.state = globals.State.STOPPING
     for t in globals.shutdown_handlers:
         safe_invoke(t)
-    for t in globals.tasks:
-        t.cancel()
     globals.state = globals.State.STOPPED
 
 
@@ -86,7 +84,7 @@ async def exception_handler_500(request: Request, exception: Exception) -> Respo
 
 
 @sio.on('handshake')
-async def handle_handshake(sid: str) -> bool:
+def handle_handshake(sid: str) -> bool:
     client = get_client(sid)
     if not client:
         return False
@@ -94,11 +92,13 @@ async def handle_handshake(sid: str) -> bool:
     sio.enter_room(sid, client.id)
     for t in client.connect_handlers:
         safe_invoke(t, client)
+    for t in globals.connect_handlers:
+        safe_invoke(t, client)
     return True
 
 
 @sio.on('disconnect')
-async def handle_disconnect(sid: str) -> None:
+def handle_disconnect(sid: str) -> None:
     client = get_client(sid)
     if not client:
         return
@@ -106,6 +106,8 @@ async def handle_disconnect(sid: str) -> None:
         delete_client(client.id)
     for t in client.disconnect_handlers:
         safe_invoke(t, client)
+    for t in globals.disconnect_handlers:
+        safe_invoke(t, client)
 
 
 @sio.on('event')
@@ -165,4 +167,6 @@ async def prune_slot_stacks() -> None:
 
 def delete_client(id: str) -> None:
     binding.remove(list(globals.clients[id].elements.values()), Element)
+    for element in globals.clients[id].elements.values():
+        element.delete()
     del globals.clients[id]
