@@ -5,11 +5,10 @@ from typing import Callable, Optional
 
 from fastapi import Request, Response
 
-from . import globals
+from . import background_tasks, globals
 from .async_updater import AsyncUpdater
 from .client import Client
 from .favicon import create_favicon_route
-from .task_logger import create_task
 
 
 class page:
@@ -46,8 +45,7 @@ class page:
         return self.dark if self.dark is not ... else globals.dark
 
     def __call__(self, func: Callable) -> Callable:
-        # NOTE we need to remove existing routes for this path to make sure only the latest definition is used
-        globals.app.routes[:] = [r for r in globals.app.routes if getattr(r, 'path', None) != self.path]
+        globals.app.remove_route(self.path)  # NOTE make sure only the latest route definition is used
         parameters_of_decorated_func = list(inspect.signature(func).parameters.keys())
 
         async def decorated(*dec_args, **dec_kwargs) -> Response:
@@ -62,9 +60,9 @@ class page:
                 async def wait_for_result() -> None:
                     with client:
                         await AsyncUpdater(result)
-                task = create_task(wait_for_result())
+                task = background_tasks.create(wait_for_result())
                 deadline = time.time() + self.response_timeout
-                while task and not client.is_waiting_for_handshake and not task.done():
+                while task and not client.is_waiting_for_connection and not task.done():
                     if time.time() > deadline:
                         raise TimeoutError(f'Response not ready after {self.response_timeout} seconds')
                     await asyncio.sleep(0.1)
